@@ -1,35 +1,51 @@
-import time
-import json
-import random
-import logging
 import hashlib
-import requests
+import json
+import logging
+import random
+import time
 from json.decoder import JSONDecodeError
 
+import requests
+
 from instagrapi import config
-from instagrapi.utils import generate_signature
 from instagrapi.exceptions import (
-    ClientError,
-    ClientConnectionError,
-    ClientNotFoundError,
-    ClientJSONDecodeError,
-    ClientForbiddenError,
-    ClientBadRequestError,
-    ClientThrottledError,
-    ClientRequestTimeout,
-    FeedbackRequired,
-    ChallengeRequired,
-    LoginRequired,
-    SentryBlock,
-    RateLimitError,
     BadPassword,
+    ChallengeRequired,
+    ClientBadRequestError,
+    ClientConnectionError,
+    ClientError,
+    ClientForbiddenError,
+    ClientJSONDecodeError,
+    ClientNotFoundError,
+    ClientRequestTimeout,
+    ClientThrottledError,
+    FeedbackRequired,
+    LoginRequired,
     PleaseWaitFewMinutes,
-    VideoTooLongException,
+    RateLimitError,
+    SentryBlock,
     UnknownError,
+    VideoTooLongException,
 )
+from instagrapi.utils import generate_signature
 
 
-def manual_input_code(self, username, choice=None):
+def manual_input_code(self, username: str, choice=None):
+    """
+    Manual security code helper
+
+    Parameters
+    ----------
+    username: str
+        User name of a Instagram account
+    choice: optional
+        Whether sms or email
+
+    Returns
+    -------
+    str
+        Code
+    """
     code = None
     choice_name = {0: 'sms', 1: 'email'}.get(choice)
     while True:
@@ -40,6 +56,9 @@ def manual_input_code(self, username, choice=None):
 
 
 class PrivateRequestMixin:
+    """
+    Helpers for private request
+    """
     private_requests_count = 0
     handle_exception = None
     challenge_code_handler = manual_input_code
@@ -57,9 +76,23 @@ class PrivateRequestMixin:
         super().__init__(*args, **kwargs)
 
     def small_delay(self):
+        """
+        Small Delay
+
+        Returns
+        -------
+        Void
+        """
         time.sleep(random.uniform(0.75, 3.75))
 
     def very_small_delay(self):
+        """
+        Very small delay
+
+        Returns
+        -------
+        Void
+        """
         time.sleep(random.uniform(0.175, 0.875))
 
     @property
